package OgreMaterials;

# uses a very naive approach to read the basic material properties
#
# Written by Martin Correll for GameCat, contact: mac AT gamecat DOT de
# Licence: Perl Artistic Licence (http://www.perl.com/pub/a/language/misc/Artistic.html)

use strict;
use File::Find;

use constant DEFAULT_OGRE_TEXTURE_PATH	=> qq'D:/cvs/ogrenew/Samples/Media/materials/textures/';
use constant DEBUG => 0;

my $object = {};


sub new {
	my ($class, %args) = @_;
	my $self = {};
	foreach ( keys %args ) {
		$self->{$_} = $args{$_};
	}

	$self->{textures} ||= DEFAULT_OGRE_TEXTURE_PATH;
	warn "path for textures $self->{textures} does not exist!\n" unless -e $self->{textures};
	$self->{textures} .= "/" unless $self->{textures} =~ m|\/$|;

	bless($self, $class);
	$object = $self;
	return($self);
}


sub add_file {
	my ($self, $material_file) = @_;

	my $current_material;
	open( MATERIAL, $material_file ) or die "Could not open " . $material_file . ": $!";
	while ( <MATERIAL> ) {
		if (/^\s*material\s+(.+)/) {
			$current_material = $1;
		}
		if ( /^\s*ambient\s+(.+)\s+(.+)\s+(.+)/ ) {
			if ($current_material) {
				$self->{ $current_material }->{ambient} = [$1, $2, $3];
			}
		}
		if ( /^\s*diffuse\s+(.+)\s+(.+)\s+(.+)/ ) {
			if ($current_material) {
				$self->{ $current_material }->{diffuse} = [$1, $2, $3];
			}
		}
		if ( /^\s*texture\s+(.+)/ ) {
			if ($current_material) {
				warn "registerered material [$current_material] with texture [" . $self->{textures} . $1 . "]\n" if DEBUG;
				$self->{ $current_material }->{texture} = $1;
				$self->{ $current_material }->{texture_with_path} = $self->{textures} . $1;
			}
		}
	}
	close MATERIAL;
}


sub add_paths {
	my ($self, @paths) = @_;
	find(\&wanted, @paths);
}


sub wanted {
	return unless /\.material$/;
	$object->add_file( $File::Find::name );
}

1;
