#!/usr/bin/perl

# simple tool to convert Ogre mesh xml files to ase files (3ds MAX ascii file).
#
# Written by Martin Correll for GameCat, contact: mac AT gamecat DOT de
# Licence: Perl Artistic Licence (http://www.perl.com/pub/a/language/misc/Artistic.html)

use strict;
use warnings;
use Data::Dumper;	# for debugging
use Getopt::Long;

use OgreMaterials;
use AseWriter;

use constant DEFAULT_MATERIALS => "D:/cvs/ogrenew/Samples/Media/materials/scripts/";

my $mesh;
my $materials;
my $textures;
GetOptions(
	'xml=s'			=> \$mesh,
	'materials=s'	=> \$materials,
	'textures=s'	=> \$textures,
);

$materials ||= DEFAULT_MATERIALS;
warn "path for materials $materials does not exist!\n" unless -e $materials;
$materials .= "/" unless $materials =~ m|\/$|;

unless ( $mesh ) {
	die 'usage: mesh2ase.pl -x file.mesh.xml [-m materialpath] [-t texturepath] > output.ase' . "\n";
}

# cache materials
my $ogre_materials = OgreMaterials->new( textures => $textures );
$ogre_materials->add_paths( $materials );

# conversion
my $ase = AseWriter->new( ogre_materials => $ogre_materials );
$ase->read_xml( $mesh );
$ase->write();
